@@ -77,7 +77,9 @@ func main() {
 	configRules = append(configRules, rules.GitHubOauth())
 	configRules = append(configRules, rules.GitHubApp())
 	configRules = append(configRules, rules.GitHubRefresh())
-	configRules = append(configRules, rules.Gitlab())
+	configRules = append(configRules, rules.GitlabPat())
+	configRules = append(configRules, rules.GitlabPipelineTriggerToken())
+	configRules = append(configRules, rules.GitlabRunnerRegistrationToken())
 	configRules = append(configRules, rules.GitterAccessToken())
 	configRules = append(configRules, rules.GrafanaApiKey())
 	configRules = append(configRules, rules.GrafanaCloudApiToken())
