@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
 
@@ -10,14 +11,14 @@ func Contentful() *config.Rule {
 		Description: "Contentful delivery API token",
 		RuleID:      "contentful-delivery-api-token",
 		Regex: generateSemiGenericRegex([]string{"contentful"},
-			`[a-z0-9\-=_]{43}`),
+			alphaNumericExtended("43")),
 		SecretGroup: 1,
 		Keywords:    []string{"contentful"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("contentful", sampleExtendedAlphaNumeric43Token),
+		generateSampleSecret("contentful", secrets.NewSecret(alphaNumeric("43"))),
 	}
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
