@@ -9,7 +9,7 @@ func DropBoxAPISecret() *config.Rule {
 	// define rule
 	r := config.Rule{
 		Description: "Dropbox API secret",
-		RuleID:      "doppler-api-token",
+		RuleID:      "dropbox-api-token",
 		Regex:       generateSemiGenericRegex([]string{"dropbox"}, alphaNumeric("15")),
 		SecretGroup: 1,
 		Keywords:    []string{"dropbox"},
