@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
 
@@ -9,14 +10,14 @@ func FastlyAPIToken() *config.Rule {
 	r := config.Rule{
 		Description: "Fastly API key",
 		RuleID:      "fastly-api-token",
-		Regex:       generateSemiGenericRegex([]string{"fastly"}, extendedAlphaNumeric32),
+		Regex:       generateSemiGenericRegex([]string{"fastly"}, alphaNumericExtended("32")),
 		SecretGroup: 1,
 		Keywords:    []string{"fastly"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("fastly", sampleExtendedAlphaNumeric32Token),
+		generateSampleSecret("fastly", secrets.NewSecret(alphaNumericExtended("32"))),
 	}
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
