@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
 
@@ -9,14 +10,14 @@ func Intercom() *config.Rule {
 	r := config.Rule{
 		Description: "Intercom API Token",
 		RuleID:      "intercom-api-key",
-		Regex:       generateSemiGenericRegex([]string{"intercom"}, extendedAlphaNumeric60),
+		Regex:       generateSemiGenericRegex([]string{"intercom"}, alphaNumericExtended("60")),
 		SecretGroup: 1,
 		Keywords:    []string{"intercom"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("intercom", sampleExtendedAlphaNumeric60Token),
+		generateSampleSecret("intercom", secrets.NewSecret(alphaNumericExtended("60"))),
 	}
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
