@@ -24,6 +24,16 @@ func location(fragment Fragment, matchIndex []int) Location {
 	// default startLineIndex to 0
 	location.startLineIndex = 0
 
+	// Fixes: https://github.com/zricethezav/gitleaks/issues/1037
+	// When a fragment does NOT have any newlines, a default "newline"
+	// will be counted to make the subsequent location calculation logic work
+	// for fragments will no newlines.
+	if len(fragment.newlineIndices) == 0 {
+		fragment.newlineIndices = [][]int{
+			{len(fragment.Raw), len(fragment.Raw) + 1},
+		}
+	}
+
 	for lineNum, pair := range fragment.newlineIndices {
 		_lineNum = lineNum
 		newLineByteIndex := pair[0]
