@@ -16,6 +16,7 @@ func writeCsv(f []Finding, w io.WriteCloser) error {
 	err := cw.Write([]string{"RuleID",
 		"Commit",
 		"File",
+		"SymlinkFile",
 		"Secret",
 		"Match",
 		"StartLine",
@@ -35,6 +36,7 @@ func writeCsv(f []Finding, w io.WriteCloser) error {
 		err = cw.Write([]string{f.RuleID,
 			f.Commit,
 			f.File,
+			f.SymlinkFile,
 			f.Secret,
 			f.Match,
 			strconv.Itoa(f.StartLine),
